@@ -2,6 +2,6 @@ from . import transform_utils
 from . import plot_utils
 from . import kin_utils
 from . import collision_utils
-from . import obstacle_utils
+from . import object_utils
 from . import mesh_utils
 from . import log_utils
\ No newline at end of file
